import { Component, OnInit } from '@angular/core';
import { CommonModule } from '@angular/common';
import { UsersService } from '../../services/users.service';
import { UserDTO } from '../../model/UserDTO';

@Component({
  selector: 'app-users',
  templateUrl: './users.component.html',
  styleUrls: ['./users.component.css'],
  imports: [CommonModule]
})
export class UsersComponent implements OnInit {
  users: UserDTO[] = [];
  message: string = '';
  messageType: 'success' | 'error' = 'success';
  showConfirmModal: boolean = false;
  userToDelete: UserDTO | null = null;

  constructor(private usersService: UsersService) {}

  ngOnInit(): void {
    this.loadUsers();
  }

  private loadUsers(): void {
    this.usersService.loadUsers().subscribe(
      (users: UserDTO[]) => {
        this.users = users;
      }
    );
  }

  openDeleteModal(user: UserDTO): void {
    this.userToDelete = user;
    this.showConfirmModal = true;
  }

  closeModal(): void {
    this.showConfirmModal = false;
    this.userToDelete = null;
  }

  confirmDelete(): void {
    if (this.userToDelete) {
      this.usersService.deleteUser(this.userToDelete.uid).subscribe({
        next: (response) => {
          this.message = response.message;
          this.messageType = 'success';
          this.loadUsers();
          this.closeModal();
        },
        error: (error) => {
          this.message = error.detail || "Une erreur est survenue";
          this.messageType = 'error';
          this.closeModal();
        }
      });
    }
  }
} 